# Scripts

Scripts are a collection of code snippets or even fully functional code modules. They have been usefull in the past or are still in use for various local tasks.

# Currently available 
- transform_oem141_oem151.py - A pure python based script to transform oemetadata version 1.4 JSON strings to the newer oemetadata version 1.5.1. 